@@ -44,6 +44,7 @@ const struct vpn_config invalid_cfg = {
 	.username = {'\0'},
 	.password = {'\0'},
 	.password_set = 0,
+	.cookie = NULL,
 	.otp = {'\0'},
 	.otp_prompt = NULL,
 	.otp_delay = -1,
@@ -268,6 +269,10 @@ int load_config(struct vpn_config *cfg, const char *filename)
 				continue;
 			}
 			cfg->otp_delay = otp_delay;
+		} else if (strcmp(key, "cookie") == 0) {
+			log_warn("Ignoring option \"%s\" in the config file.\n", key);
+		} else if (strcmp(key, "cookie-on-stdin") == 0) {
+			log_warn("Ignoring option \"%s\" in the config file.\n", key);
 		} else if (strcmp(key, "no-ftm-push") == 0) {
 			int no_ftm_push = strtob(val);
 
@@ -346,13 +351,15 @@ int load_config(struct vpn_config *cfg, const char *filename)
 			cfg->pppd_call = strdup(val);
 #else
 		} else if (strcmp(key, "pppd") == 0) {
-			log_warn("Ignoring pppd option \"%s\".\n", key);
+			log_warn("Ignoring pppd option \"%s\" in the config file.\n",
+			         key);
 #endif
 		} else if (strcmp(key, "ppp-system") == 0) {
 #if HAVE_USR_SBIN_PPP
 			cfg->ppp_system = strdup(val);
 #else
-			log_warn("Ignoring option \"%s\".\n", key);
+			log_warn("Ignoring option \"%s\" in the config file.\n",
+			         key);
 #endif
 		} else if (strcmp(key, "use-resolvconf") == 0) {
 #if HAVE_RESOLVCONF
@@ -365,7 +372,8 @@ int load_config(struct vpn_config *cfg, const char *filename)
 			}
 			cfg->use_resolvconf = use_resolvconf;
 #else
-			log_warn("Ignoring option \"%s\".\n", key);
+			log_warn("Ignoring option \"%s\" in the config file.\n",
+			         key);
 #endif
 		} else if (strcmp(key, "use-syslog") == 0) {
 			int use_syslog = strtob(val);
@@ -462,6 +470,7 @@ void destroy_vpn_config(struct vpn_config *cfg)
 {
 	free(cfg->otp_prompt);
 	free(cfg->pinentry);
+	free(cfg->cookie);
 #if HAVE_USR_SBIN_PPPD
 	free(cfg->pppd_log);
 	free(cfg->pppd_plugin);
@@ -505,6 +514,10 @@ void merge_config(struct vpn_config *dst, struct vpn_config *src)
 		dst->otp_delay = src->otp_delay;
 	if (src->no_ftm_push != invalid_cfg.no_ftm_push)
 		dst->no_ftm_push = src->no_ftm_push;
+	if (src->cookie != invalid_cfg.cookie) {
+		free(dst->cookie);
+		dst->cookie = src->cookie;
+	}
 	if (src->pinentry) {
 		free(dst->pinentry);
 		dst->pinentry = src->pinentry;
